
The waterEntropy Python package
===============================

Calculate the entropy of interfacial water molecules from molecular dynamics
simulations.

``waterEntropy`` is available at https://github.com/jkalayan/waterEntropy

.. image:: images/waterentropy_logo_grey.png
    :width: 400px
    :align: center
    :target: https://github.com/jkalayan/waterEntropy

.. toctree::
   :maxdepth: 2

   user_guide/index
   API documentation <apidoc/waterEntropy>

Related works:

.. highlights::
    Kalayan J, Chakravorty A, Warwicker J, Henchman RH.
    *Total free energy analysis of fully hydrated proteins.*,
    Proteins. (2023); 91(1): 74-90. https://doi.org/10.1002/prot.26411

.. highlights::
    Kalayan J, Curtis RA, Warwicker J, Henchman RH.
    *Thermodynamic Origin of Differential Excipient-Lysozyme Interactions*,
    Front. Mol. Biosci. 8:689400 (2021). https://doi.org/10.3389/fmolb.2021.689400

.. highlights::
    Kalayan J and Henchman RH.
    *Convergence behaviour of solvation shells in simulated liquids.*,
    Phys. Chem. Chem. Phys., (2021), 23, 4892. https://doi.org/10.1039/D0CP05903J

.. highlights::
    Ali, H.S., Chakravorty, A., Kalayan, J. et al.
    *Energy–entropy method using multiscale cell correlation to calculate binding free energies in the SAMPL8 host–guest challenge.*,
    J Comput Aided Mol Des 35, 911–921 (2021). https://doi.org/10.1007/s10822-021-00406-5

.. highlights::
    Falcioni, F., Kalayan, J. & Henchman, R.H.
    *Energy-entropy prediction of octanol–water logP of SAMPL7 N-acyl sulfonamide bioisosters.*,
    J Comput Aided Mol Des 35, 831–840 (2021). https://doi.org/10.1007/s10822-021-00401-w

If you use this package in your research, please cite the following work:

.. highlights:: TBD, watch this space.


``waterEntropy`` is released under the MIT license.

Please contact Jas Kalayan jas.kalayan@stfc.ac.uk for information concerning ``waterEntropy``.

Funding
=======

Contributors to waterEntropy were supported by:

.. image:: images/ccpbiosim-logo-white-background.png
   :height: 100px
   :target: https://www.ccpbiosim.ac.uk/

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
